<?php

/*
 * Model Admin
 * Модель Администратора
 */
class AdminCls
{
    /*
     * Getting parameters of a Admin
     * Получение параметров Администратора
     * return $admincls array  -  the array of parameters of the Admin  -  массив параметров Администратора
     */
    public static function getAdmin()
    {
        global $mysqli;
        $admincls = [];
        $query = "SELECT id, login, password FROM admin_table";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->execute();
            $stmt->bind_result(
                $admincls['id'], $admincls['login'], $admincls['password']
            );
            $stmt->fetch();
            $stmt->close();
        }
        return $admincls;
    }

	
	
    /*
     * Is Admin? (case insensitive)
     * Это администратор? (без учёта регистра)
     */
    public static function isAdmin($login, $password)
    {
        global $mysqli;
        $admincls = AdminCls::getAdmin();
		 return strcasecmp($login, $admincls['login']) == 0 && strcasecmp($password, $admincls['password']) == 0;
    }
	

	
    /*
     * Adding Admin
     * Добавление Администратора
     */
    public static function addAdmin($login = 'admin', $password = 'admin')
    {
        global $mysqli;
        $admincls = [];
        $query = "INSERT INTO admin_table (login, password) VALUES (?, ?)";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('ss', $login, $password);
            $stmt->execute();
			$admincls['id'] = $stmt->insert_id;
            $stmt->close();
        }
		$admincls['login'] = $login;
		$admincls['password'] = $password;
        return $admincls;
    }



    /*
     * Editing Admin
     * Редактирование Администратора
     */
    public static function editAdmin($id, $login, $password)
    {
        global $mysqli;
        $query = "UPDATE admin_table SET login=?, password=? WHERE id=?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('ssi', $login, $password, $id);
            $stmt->execute();
            $stmt->close();
        }
    }	
	

	
    /*
     * Send password (we create the administrator if it was not)
     * Отправка пароля на почту (создаём администратора, если его не было)
     */
    public static function SendPassword($email)
    {
        global $mysqli;
        $admincls = [];
		if (CheckMail(FEEDBACK_EMAIL)) {
		    if (strcasecmp($email, FEEDBACK_EMAIL) == 0) {
                $query = "SELECT id, login, password FROM admin_table";
                if ($stmt = $mysqli->prepare($query)) {
                    $stmt->execute();
					$stmt->store_result(); // for $stmt->num_rows working
                    $stmt->bind_result(
                    $admincls['id'], $admincls['login'], $admincls['password']
                    );
                    $stmt->fetch();
				    // If 0 rows - just add new default Admin
				    if (!($stmt->num_rows)){
					    $admincls = AdminCls::addAdmin();
				    }
                    $stmt->close();
				
                    return SendMail(FEEDBACK_EMAIL, "Admin", "Admin login: " . $admincls['login'], "Password: " . $admincls['password']);
                }
		    } else {
			    // $email not equivalent FEEDBACK_EMAIL
			    return false;
			}
		} else {
		    // not valid FEEDBACK_EMAIL
			return false;
		}
    }
}
?>