<?php

/*
 * Model Lottery
 * Модель Лотерея
 */
class Lottery
{
    /*
     * Getting parameters of a Lottery by id
     * Получение параметров Лотереи по id
     * $id integer id Lottery id Лотереи
     * return $lottery array  -  the array of parameters of the Lottery  -  массив параметров Лотереи
     */
    public static function getLotteryById($id)
    {
        global $mysqli;
        $lottery = [];
        $query = "SELECT id, name, description, date_creation, date_draw
            FROM lottery
            WHERE id = ?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $id);
            $stmt->execute();
            $stmt->bind_result(
                $lottery['id'], $lottery['name'], $lottery['description'], $lottery['date_creation'], $lottery['date_draw']
            );
            $stmt->fetch();
            $stmt->close();
        }
        return $lottery;
    }
	
	
	
    /*
     * Getting all Lotteries
     * Получение всех Лотерей
     * $id integer id Lottery id Лотереи
     * return $lottery array  -  the array of parameters of the Lottery  -  массив параметров Лотереи
     */
    public static function getLotteries()
    {
        global $mysqli;
        $lottery = [];
        $query = "SELECT id, name, description, date_creation, date_draw
            FROM lottery ORDER BY id";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->execute();
            $stmt->bind_result($id, $name, $description, $date_creation, $date_draw);
            while ($stmt->fetch()) {
                $lottery[] = ['id' => $id, 'name' => $name, 'description' => $description, 'date_creation' => $date_creation, 'date_draw' => $date_draw];
            }
            $stmt->close();
        }
        return $lottery;
    }


	
    /*
     * Adding Lottery
     * Добавление Лотереи
     */
    public static function addLottery($name, $description, $date_draw)
    {
        global $mysqli;

		if (CheckEmptyFieldExist(array($name))) {
		    return "emptyfieldfound"; // Found an empty field
		}
		
		if (bCheckDate($date_draw)) {
        	$query = "INSERT INTO lottery (name, description, date_draw) VALUES (?, ?, ?)";
        	if ($stmt = $mysqli->prepare($query)) {
           		$stmt->bind_param('sss', $name, $description, dnParseDate($date_draw));
           		$stmt->execute();
           		$id = $stmt->insert_id;
           		$stmt->close();
        	}
			return $id; // ok
		} else {
		   	return "notvaliddate"; // notvaliddate
		}
    }



    /*
     * Editing Lottery
     * Редактирование Лотереи
     */
    public static function editLottery($id, $name, $description, $date_draw)
    {
        global $mysqli;

		if (CheckEmptyFieldExist(array($name))) {
		    return "emptyfieldfound"; // Found an empty field
		}
		
		if (bCheckDate($date_draw)) {
            $query = "UPDATE lottery SET name=?, description=?, date_draw=? WHERE id=?";
            if ($stmt = $mysqli->prepare($query)) {
                $stmt->bind_param('sssi', $name, $description, dnParseDate($date_draw), $id);
                $stmt->execute();
                $stmt->close();
				return $id; // ok
            }
		} else {
		   	return "notvaliddate"; // notvaliddate
		}
    }	



    /*
     * Delete Lottery
     * Удаление Лотереи
     */
    public static function deleteLottery($id)
    {
        global $mysqli;

		if (Lottery::bLotteryWinnerExist($id)) {
			return "linkexist";
		}
		
		if (Lottery::bLotteryPrizeLinkExist($id)) {
			return "linkexist";
		}
		
        $query = "DELETE from lottery WHERE id=?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $id);
            $stmt->execute();
            $stmt->close();
        }
    }
	
	
	
	// Determine the winner (id = idLottery)
    public static function determineLotteryWinner($id)
    {
        global $mysqli;
        $persons = [];
		$iSum = null;
		
		if (Lottery::bLotteryWinnerExist($id)) {
			return "winneralreadyexist";
		} else {
		// Determine the total number of tickets
		// The first ticket will win with 1, the last with the last number dropped
		// Определяем общее количество билетов
		// 1-ый билет выиграет при 1, последний при последнем выпавшем числе
		$query = "SELECT SUM(number_of_tickets)
        FROM persona
        WHERE active = 1";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->execute();
            $stmt->bind_result($iSum);
            $stmt->fetch();
            $stmt->close();
        }
		
		$iWinner = mt_rand(1, $iSum);
		
		// Determine who owns the fallen ticket - go through the array [idPerson, number_of_tickets], adding the total number number_of_tickets
		// As soon as this amount is greater than or equal to the generated number - we are our winner, we exit the cycle
		// Определяем кому принадлежит выпавший билет - идём по массиву [idPerson, number_of_tickets], прибавляя общее количество number_of_tickets
		// Как только эта сумма больше или равна сгенерированного числа - мы наши победителя, выходим из цикла
		$iCount = 0;
		$persons = Persona::getPersons(true);
		
		foreach ($persons as $person) :
			$iCount = $iCount + $person['number_of_tickets'];
			if ($iCount >= $iWinner) {
        		$query = "INSERT INTO persona_lottery (id_persona, id_lottery) VALUES (?, ?)";
        		if ($stmt = $mysqli->prepare($query)) {
           			$stmt->bind_param('ii', $person['id'], $id);
           			$stmt->execute();
           			$stmt->close();
        		}
				//return $person;
				break;
			}
		endforeach;
		}
		
		// Set number_of_tickets = 0 (active persons only)
        $query = "UPDATE persona SET number_of_tickets = 0 WHERE active=1";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->execute();
            $stmt->close();
        }
    }
	
	
	
	// Get the winner (id = idLottery)
	public static function getLotteryWinner($id)
    {
		global $mysqli;
        $persons = [];
        $query = "SELECT p.id, p.name, p.game_login, p.discord_username, p.email, p.password, p.date_of_birth, p.date_of_registration, p.number_of_tickets, p.active, pl.id
            FROM persona as p JOIN persona_lottery as pl
            ON p.id = pl.id_persona 
			WHERE pl.id_lottery = ? ORDER BY p.id";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $id);
            $stmt->execute();
            $stmt->bind_result($id, $name, $game_login, $discord_username, $email, $password, $date_of_birth, $date_of_registration, $number_of_tickets, $active, $pl_id);
            while ($stmt->fetch()) {
                $persons[] = ['id' => $id, 'name' => $name, 'game_login' => $game_login, 'discord_username' => $discord_username, 'email' => $email, 'password' => $password, 'date_of_birth' => $date_of_birth, 'date_of_registration' => $date_of_registration, 'number_of_tickets' => $number_of_tickets, 'active' => $active, 'pl_id' => $pl_id];
            }
            $stmt->close();
        }
        return $persons;
    }
	
	
	
	// Lottery winner exist? (id = idLottery)
	public static function bLotteryWinnerExist($id)
    {
		global $mysqli;
        $query = "SELECT COUNT(*) 
            FROM persona_lottery 
			WHERE id_lottery = ?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $id);
            $stmt->execute();
            $stmt->bind_result($iCount);
            $stmt->fetch();
            $stmt->close();
        }
        return $iCount > 0;
    }
	
	
	
    /*
     * Link with Prize exist?
     * Привязан ли к этой лотерее хоть один приз
     */
    public static function bLotteryPrizeLinkExist($idLottery)
    {
        global $mysqli;
        $query = "SELECT COUNT(*) 
            FROM prize_lottery 
			WHERE id_lottery = ?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $idLottery);
            $stmt->execute();
            $stmt->bind_result($iCount);
            $stmt->fetch();
            $stmt->close();
        }
        return $iCount > 0;
    }
	
	
	
	// Add +1 ticket to all active persons
	public static function plusOneTicket()
    {
		global $mysqli;
        $query = "UPDATE persona SET number_of_tickets = number_of_tickets + 1 WHERE active=1";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->execute();
            $stmt->close();
        }
    }
}
?>