<?php

/*
 * Model Persona
 * Модель Персоны
 */
class Persona
{
    /*
     * Is Persona login?
     * Это Персона логинится?
     */
    public static function isPersona($game_login, $password)
    {
        global $mysqli;
		
		$id_return = 0;
        $query = "SELECT id 
            FROM persona
            WHERE game_login = ? AND password = ?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('ss', $game_login, $password);
            $stmt->execute();
            $stmt->bind_result($id);
            if ($stmt->fetch()) {
                $id_return = $id;
			}
            $stmt->close();
        }
        return $id_return;
    }
	
	
	
    /*
     * Getting parameters of a Person by id
     * Получение параметров Персоны по id
     * $id integer id Person id Персоны
     * return $persona array  -  the array of parameters of the Person  -  массив параметров Персоны
     */
    public static function getPersonaById($id)
    {
        global $mysqli;
        $persona = [];
        $query = "SELECT id, name, game_login, discord_username, email, password, date_of_birth, date_of_registration, number_of_tickets, active
            FROM persona
            WHERE id = ?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $id);
            $stmt->execute();
            $stmt->bind_result(
                $persona['id'], $persona['name'], $persona['game_login'], $persona['discord_username'], $persona['email'], $persona['password'], $persona['date_of_birth'], $persona['date_of_registration'], $persona['number_of_tickets'], $persona['active']
            );
            $stmt->fetch();
            $stmt->close();
        }
        return $persona;
    }
	
	
	
    /*
     * Getting all Persons
     * Получение всех Персон
     * $id integer id Person id Персоны
     * return $persona array  -  the array of parameters of the Person  -  массив параметров Персоны
     */
    public static function getPersons($bActive = false)
    {
        global $mysqli;
        $persons = [];
        $query = "SELECT id, name, game_login, discord_username, email, password, date_of_birth, date_of_registration, number_of_tickets, active
            FROM persona " . (($bActive) ? " WHERE active = 1" : "") ." ORDER BY active DESC, number_of_tickets DESC, id";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->execute();
            $stmt->bind_result($id, $name, $game_login, $discord_username, $email, $password, $date_of_birth, $date_of_registration, $number_of_tickets, $active);
            while ($stmt->fetch()) {
                $persons[] = ['id' => $id, 'name' => $name, 'game_login' => $game_login, 'discord_username' => $discord_username, 'email' => $email, 'password' => $password, 'date_of_birth' => $date_of_birth, 'date_of_registration' => $date_of_registration, 'number_of_tickets' => $number_of_tickets, 'active' => $active];
            }
            $stmt->close();
        }
        return $persons;
    }


	
    /*
     * Adding Person
     * Добавление Персоны
     */
    public static function addPersona($name, $game_login, $discord_username, $email, $password, $date_of_birth, $active)
    {
        global $mysqli;

		if (CheckEmptyFieldExist(array($name, $game_login, $discord_username, $email, $password))) {
		    return "emptyfieldfound"; // Found an empty field
		}
		
		if (!(CheckUniqueField('persona', 'game_login', $game_login))) {
		    return "loginalreadyexist"; // login already exist
		}
		
		if (!(CheckUniqueField('persona', 'email', $email))) {
		    return "emailalreadyexist"; // email already exist
		}
		
        if (CheckMail($email))
        {
			if (bCheckDate($date_of_birth)) {
        		$query = "INSERT INTO persona (name, game_login, discord_username, email, password, date_of_birth, active) VALUES (?, ?, ?, ?, ?, ?, ?)";
        		if ($stmt = $mysqli->prepare($query)) {
            		$stmt->bind_param('ssssssi', $name, $game_login, $discord_username, strtolower($email), $password, dnParseDate($date_of_birth), $active);
            		$stmt->execute();
            		$id = $stmt->insert_id;
            		$stmt->close();
        		}
				return $id; // ok
			} else {
		    	return "notvaliddate"; // notvaliddate
			}
        } else {
		    return "notvalidemail"; // notvalidemail
        }
    }



    /*
     * Editing Person (without number_of_tickets)
     * Редактирование Персоны (без кол-ва билетов)
     */
    public static function editPersona($id, $name, $game_login, $discord_username, $email, $password, $date_of_birth, $active)
    {
        global $mysqli;

		if (CheckEmptyFieldExist(array($name, $game_login, $discord_username, $email, $password))) {
		    return "emptyfieldfound"; // Found an empty field
		}
		
		if (!(CheckUniqueField('persona', 'game_login', $game_login, $id))) {
		    return "loginalreadyexist"; // login already exist
		}		
		
		if (!(CheckUniqueField('persona', 'email', $email, $id))) {
		    return "emailalreadyexist"; // email already exist
		}
		
        if (CheckMail($email))
        {
			if (bCheckDate($date_of_birth)) {
                $query = "UPDATE persona SET name=?, game_login=?, discord_username=?, email=?, password=?, date_of_birth=?, active=? WHERE id=?";
                if ($stmt = $mysqli->prepare($query)) {
                    $stmt->bind_param('ssssssii', $name, $game_login, $discord_username, strtolower($email), $password, dnParseDate($date_of_birth), $active, $id);
                    $stmt->execute();
                    $stmt->close();
					return $id; // ok
                }
			} else {
		    	return "notvaliddate"; // notvaliddate
			}
        } else {
		    return "notvalidemail"; // notvalidemail
        }
    }	



    /*
     * Delete Person
     * Удаление Персоны
     */
    public static function deletePersona($id)
    {
        global $mysqli;
		
		if (Persona::isWinner($id)) {
			return "linkexist";
		}
		
        $query = "DELETE from persona WHERE id=?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $id);
            $stmt->execute();
            $stmt->close();
        }
    }
	
	
	
    /*
     * Update number of tickets for Person
     * Изменить количество билетов Персоны
     */
    public static function updateNumberOfTickets($number_of_tickets, $id)
    {
        global $mysqli;
		if (is_numeric($number_of_tickets)) {
			if ($number_of_tickets >= 0) {
                $query = "UPDATE persona SET number_of_tickets=? WHERE id=?";
                if ($stmt = $mysqli->prepare($query)) {
                    $stmt->bind_param('ii', $number_of_tickets, $id);
                    $stmt->execute();
                    $stmt->close();
                }
            }
		}
    }
	
	
	
    /*
     * Change Activity for Person
     * Поменять Активность Персоны
     */
    public static function ChangeActivityPerson($id, $CurrentActivity)
    {
        global $mysqli;
        if ($CurrentActivity == 1) {
			$CurrentActivity = 0;
		} else {
			$CurrentActivity = 1;
		}
        $query = "UPDATE persona SET active=". $CurrentActivity ." WHERE id=?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $id);
            $stmt->execute();
            $stmt->close();
		}
    }

	
	
    public static function SendPassword($email)
    {
        global $mysqli;
		if (CheckMail($email)) {
            $query = "SELECT name, game_login, password FROM persona WHERE email='". strtolower($email) ."'";
            if ($stmt = $mysqli->prepare($query)) {
                $stmt->execute();
				$stmt->store_result(); // for $stmt->num_rows working
                $stmt->bind_result($name, $game_login, $password);
                $stmt->fetch();
				$bEMailExist = $stmt->num_rows > 0;
                $stmt->close();
			    // If >0 rows - we have this E-Mail in database
			    if ($bEMailExist){
                    return SendMail($email, $name, "Your login: " . $game_login, "Password: " . $password);
			    // If 0 rows - just E-Mail not found
			    } else {
			        return false;
				}
            }
		} else {
		    // not valid $email
			return false;
		}
    }

	
	
    public static function isWinner($id)
    {
        global $mysqli;
        $query = "SELECT COUNT(*) 
            FROM persona_lottery 
			WHERE id_persona = ?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $id);
            $stmt->execute();
            $stmt->bind_result($iCount);
            $stmt->fetch();
            $stmt->close();
        }
        return $iCount > 0;
    }
}
?>