<?php

/*
 * Model Prize
 * Модель Приз
 */
class Prize
{
    /*
     * Getting parameters of a Prize by id
     * Получение параметров Приза по id
     * $id integer id Prize id Приза
     * return $prize array  -  the array of parameters of the Prize  -  массив параметров Приза
     */
    public static function getPrizeById($id)
    {
        global $mysqli;
        $prize = [];
        $query = "SELECT id, name, description, date_creation
            FROM prize
            WHERE id = ?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $id);
            $stmt->execute();
            $stmt->bind_result(
                $prize['id'], $prize['name'], $prize['description'], $prize['date_creation']
            );
            $stmt->fetch();
            $stmt->close();
        }
        return $prize;
    }
	
	
	
    /*
     * Getting all Prizes
     * Получение всех Призов
     * $id integer id Prize id Приза
     * return $prize array  -  the array of parameters of the Prize  -  массив параметров Приза
     */
    public static function getPrizes()
    {
        global $mysqli;
        $prizes = [];
        $query = "SELECT id, name, description, date_creation
            FROM prize ORDER BY id";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->execute();
            $stmt->bind_result($id, $name, $description, $date_creation);
            while ($stmt->fetch()) {
                $prizes[] = ['id' => $id, 'name' => $name, 'description' => $description, 'date_creation' => $date_creation];
            }
            $stmt->close();
        }
        return $prizes;
    }

	
	
    /*
     * Getting Prizes by idLottery
     * Получение Призов по id Лотереи
     * return $prize array  -  the array of parameters of the Prize  -  массив параметров Приза
     */
    public static function getPrizesByIdLottery($idLottery)
    {
        global $mysqli;
        $prizes = [];
        $query = "SELECT p.id, p.name, p.description, p.date_creation, pl.id 
            FROM prize as p JOIN prize_lottery as pl
            ON p.id = pl.id_prize 
			WHERE pl.id_lottery = ? ORDER BY p.id";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $idLottery);
            $stmt->execute();
            $stmt->bind_result($id, $name, $description, $date_creation, $pl_id);
            while ($stmt->fetch()) {
                $prizes[] = ['id' => $id, 'name' => $name, 'description' => $description, 'date_creation' => $date_creation, 'pl_id' => $pl_id];
            }
            $stmt->close();
        }
        return $prizes;
    }
	
	
	
    /*
     * Adding Prize to Lottery
     * Добавление Приза в Лотерею
     */
    public static function addPrizeLottery($idPrize, $idLottery)
    {
        global $mysqli;

		$query = "INSERT INTO prize_lottery (id_prize, id_lottery) VALUES (?, ?)";
        if ($stmt = $mysqli->prepare($query)) {
        	$stmt->bind_param('ii', $idPrize, $idLottery);
        	$stmt->execute();
        	// $id = $stmt->insert_id;
        	$stmt->close();
        }
		// return $id; // ok
    }

	
	
    /*
     * Delete Prize from Lottery
     * Удаление Приза из Лотереи
     */
    public static function deletePrizeLottery($id_pl)
    {
        global $mysqli;

		$query = "DELETE FROM prize_lottery WHERE id = ?";
        if ($stmt = $mysqli->prepare($query)) {
        	$stmt->bind_param('i', $id_pl);
        	$stmt->execute();
        	$stmt->close();
        }
    }
	
	
	
    /*
     * Link with Lottery exist?
     * Привязан ли этот приз хоть к одной лотерее
     */
    public static function bPrizeLotteryLinkExist($idPrize)
    {
        global $mysqli;
        $query = "SELECT COUNT(*) 
            FROM prize_lottery 
			WHERE id_prize = ?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $idPrize);
            $stmt->execute();
            $stmt->bind_result($iCount);
            $stmt->fetch();
            $stmt->close();
        }
        return $iCount > 0;
    }
	

	
    /*
     * Adding Prize
     * Добавление Приза
     */
    public static function addPrize($name, $description)
    {
        global $mysqli;

		if (CheckEmptyFieldExist(array($name))) {
		    return "emptyfieldfound"; // Found an empty field
		}
		
		if (!(CheckUniqueField('prize', 'name', $name))) {
		    return "prizealreadyexist"; // Prize name already exist
		}

		$query = "INSERT INTO prize (name, description) VALUES (?, ?)";
        if ($stmt = $mysqli->prepare($query)) {
        	$stmt->bind_param('ss', $name, $description);
        	$stmt->execute();
        	$id = $stmt->insert_id;
        	$stmt->close();
        }
		return $id; // ok
    }



    /*
     * Editing Prize
     * Редактирование Приза
     */
    public static function editPrize($id, $name, $description)
    {
        global $mysqli;

		if (CheckEmptyFieldExist(array($name))) {
		    return "emptyfieldfound"; // Found an empty field
		}
		
		if (!(CheckUniqueField('prize', 'name', $name, $id))) {
		    return "prizealreadyexist"; // Prize name already exist
		}		
		
        $query = "UPDATE prize SET name=?, description=? WHERE id=?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('ssi', $name, $description, $id);
            $stmt->execute();
            $stmt->close();
			return $id; // ok
        }
    }



    /*
     * Delete Prize
     * Удаление Приза
     */
    public static function deletePrize($id)
    {
        global $mysqli;
		if (Prize::bPrizeLotteryLinkExist($id)) {
			return "linkexist";
		}
        $query = "DELETE from prize WHERE id=?";
        if ($stmt = $mysqli->prepare($query)) {
            $stmt->bind_param('i', $id);
            $stmt->execute();
            $stmt->close();
        }
    }
}
?>